PCB Environment: RouterResult Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
RouterResult Struct Reference

## Public Member Functions
bool | isSet () const
bool | operator== (const RouterResult &) const =default
PyObject * | getPy () const

## Data Fields
float | TrackLen {std::numeric_limits<float>::quiet_NaN()}
int16_t | NumVias {0}
int16_t | NumDisconnected {0}

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/Reward.hpp